@@ -68,12 +68,23 @@ class System(models.Model):
     class Meta(object):
         ordering = ('-modified',)
 
+    def __unicode__(self):
+        if self.name:
+            return self.name
+        if self.content_type_id:
+            return unicode(self.content_object)
+        return u'Unknown System'
+
     def __len__(self):
         return self.length
 
     def __nonzero__(self):
         return True
 
+    def __iter__(self):
+        for transition in self.transitions.iterator():
+            yield transition
+
     @transaction.commit_on_success
     def __getitem__(self, idx):
         queryset = self.transitions.order_by('start_time')
@@ -120,10 +131,6 @@ class System(models.Model):
                 raise IndexError
         return trans
 
-    def __iter__(self):
-        for transition in self.transitions.iterator():
-            yield transition
-
     @classmethod
     def get(cls, obj_or_name, save=True):
         "Returns a System instance representing this object."
